==> emodpy_covid-0.0.31-py3-none-any.whl: emodpy_covid/microstructure/add_hh_to_demo.py <==
#!/usr/bin/python3

import json
import sys
import os

def doit( primary_ids_path, household_ids_path, input_demog, output_demog ):

    if not os.path.exists( primary_ids_path ):
        print( f"ERROR: {primary_ids_path} not found." )
        return
    if not os.path.exists( household_ids_path ):
        print( f"ERROR: {household_ids_path} not found." )
        return
    if not os.path.exists( input_demog ):
        print( f"ERROR: {input_demog} not found." )
        return

    demog_json = json.loads( open( input_demog ).read() )

    # TBD: Get the list of household ids from the previous script

    INTRA_MULT = 10.0
    COM2COM_MULT = 0.1
    INTER_MULT = 0.0

    def get_props( route, ip_key, num_ids ):
        prop = {}
        prop[ "Property" ] = ip_key
        prop[ "Values" ] = []
        prop[ "Initial_Distribution" ] = []
        prop[ "Transitions" ] = []
        prop[ "TransmissionMatrix" ] = {}
        prop[ "TransmissionMatrix" ][ route ] = {}
        #prop[ "TransmissionMatrix" ][ route ][ "Matrix" ] = []
        prop[ "TransmissionMatrix" ][ route ][ "DiagMatrix" ] = {}
        prop[ "TransmissionMatrix" ][ route ][ "DiagMatrix" ][ "Diagonal" ] = INTRA_MULT 
        prop[ "TransmissionMatrix" ][ route ][ "DiagMatrix" ][ "OffDiagonal" ] = INTER_MULT 

        for hh_id in range( num_ids ):
            prop[ "Values" ].append( str( hh_id ) )
            prop[ "Initial_Distribution" ].append( 0 )
        prop[ "Initial_Distribution" ][0] = 1.0 # not this is nonsense but irrlevantly so for us. 
        return prop 

    primary_ids = json.loads( open( primary_ids_path ).read() )
    num_primaries = max(primary_ids)+3
    print( "No. Primaries = " + str( num_primaries ) )
    demog_json[ "Defaults" ][ "IndividualProperties" ][0] = get_props( "contact", "Primary", num_primaries )

    hh_ids = json.loads( open( household_ids_path ).read() )
    num_hhs = len(hh_ids) # should be 25, hunt down off-by-1 error
    print( "No. Households = " + str( num_hhs ) )

    if len(demog_json[ "Defaults" ][ "IndividualProperties" ] ) == 1:
        demog_json[ "Defaults" ][ "IndividualProperties" ].append( get_props( "environmental", "Household", num_hhs ) )
    else:
        demog_json[ "Defaults" ][ "IndividualProperties" ][1] = get_props( "environmental", "Household", num_hhs )

    print( "Finished creating demographics json. Writing to disk." )

    with open( output_demog, "w+" ) as outfile:
        json.dump( demog_json, outfile, sort_keys=True, indent=4 )

if __name__ == "__main__":
    if len( sys.argv ) < 3:
        print( f"Usage: {sys.argv[0]} <input_demog_file.json> <output_demog_file.json>" )
        sys.exit()

    doit( primary_ids, household_ids, sys.argv[1], sys.argv[2] )

==> emodpy_covid-0.0.50-py3-none-any.whl: emodpy_covid/microstructure/add_hh_to_demo.py <==
#!/usr/bin/python3

import json
import sys
import os

def doit( primary_ids_path, household_ids_path, input_demog, output_demog ):

    if not os.path.exists( primary_ids_path ):
        print( f"ERROR: {primary_ids_path} not found." )
        return
    if not os.path.exists( household_ids_path ):
        print( f"ERROR: {household_ids_path} not found." )
        return
    if not os.path.exists( input_demog ):
        print( f"ERROR: {input_demog} not found." )
        return

    demog_json = json.loads( open( input_demog ).read() )

    # TBD: Get the list of household ids from the previous script

    INTRA_MULT = 10.0
    COM2COM_MULT = 0.1
    INTER_MULT = 0.0

    def get_props( route, ip_key, num_ids ):
        prop = {}
        prop[ "Property" ] = ip_key
        prop[ "Values" ] = []
        prop[ "Initial_Distribution" ] = []
        prop[ "Transitions" ] = []
        prop[ "TransmissionMatrix" ] = {}
        prop[ "TransmissionMatrix" ][ route ] = {}
        #prop[ "TransmissionMatrix" ][ route ][ "Matrix" ] = []
        prop[ "TransmissionMatrix" ][ route ][ "DiagMatrix" ] = {}
        prop[ "TransmissionMatrix" ][ route ][ "DiagMatrix" ][ "Diagonal" ] = INTRA_MULT 
        prop[ "TransmissionMatrix" ][ route ][ "DiagMatrix" ][ "OffDiagonal" ] = INTER_MULT 
        prop[ "TransmissionMatrix" ][ route ][ "DiagMatrix" ][ "ZeroGroup" ] = INTER_MULT 

        for hh_id in range( num_ids+1 ):
            prop[ "Values" ].append( str( hh_id ) )
            prop[ "Initial_Distribution" ].append( 0 )
        prop[ "Initial_Distribution" ][0] = 1.0 # not this is nonsense but irrlevantly so for us. 
        return prop 

    primary_ids = json.loads( open( primary_ids_path ).read() )
    num_primaries = max(primary_ids)+3
    print( "No. Primaries = " + str( num_primaries ) )
    demog_json[ "Defaults" ][ "IndividualProperties" ][0] = get_props( "contact", "Primary", num_primaries )

    hh_ids = json.loads( open( household_ids_path ).read() )
    num_hhs = max(hh_ids)+1 # should be 25, hunt down off-by-1 error
    print( "No. Households = " + str( num_hhs ) )

    if len(demog_json[ "Defaults" ][ "IndividualProperties" ] ) == 1:
        demog_json[ "Defaults" ][ "IndividualProperties" ].append( get_props( "environmental", "Household", num_hhs ) )
    else:
        demog_json[ "Defaults" ][ "IndividualProperties" ][1] = get_props( "environmental", "Household", num_hhs )

    print( "Finished creating demographics json. Writing to disk." )

    with open( output_demog, "w+" ) as outfile:
        json.dump( demog_json, outfile, sort_keys=True, indent=4 )

if __name__ == "__main__":
    if len( sys.argv ) < 3:
        print( f"Usage: {sys.argv[0]} <input_demog_file.json> <output_demog_file.json>" )
        sys.exit()

    doit( primary_ids, household_ids, sys.argv[1], sys.argv[2] )
